@@ -15,14 +15,14 @@ from queue import Queue
 
 from je_auto_control.windows.mouse.win32_ctype_mouse_control import position
 
-user32 = windll.user32
-kernel32 = windll.kernel32
+_user32 = windll.user32
+_kernel32 = windll.kernel32
 """
 Left mouse button down 0x0201
 Right mouse button down 0x0204
 Middle mouse button down 0x0207
 """
-wm_mouse_key_code = [0x0201, 0x0204, 0x0207]
+_wm_mouse_key_code = [0x0201, 0x0204, 0x0207]
 
 
 class Win32MouseListener(Thread):
@@ -35,8 +35,8 @@ class Win32MouseListener(Thread):
         self.record_flag = False
         self.hook_event_code_int = 14
 
-    def _set_win32_hook(self, point):
-        self.hooked = user32.SetWindowsHookExA(
+    def _set_win32_hook(self, point) -> bool:
+        self.hooked = _user32.SetWindowsHookExA(
             self.hook_event_code_int,
             point,
             0,
@@ -46,58 +46,49 @@ class Win32MouseListener(Thread):
             return False
         return True
 
-    def _remove_win32_hook_proc(self):
+    def _remove_win32_hook_proc(self) -> None:
         if self.hooked is None:
             return
-        user32.UnhookWindowsHookEx(self.hooked)
+        _user32.UnhookWindowsHookEx(self.hooked)
         self.hooked = None
 
-    def _win32_hook_proc(self, code, w_param, l_param):
-        if w_param not in wm_mouse_key_code:
-            return user32.CallNextHookEx(self.hooked, code, w_param, l_param)
-        if w_param == wm_mouse_key_code[0] and self.record_flag is True:
+    def _win32_hook_proc(self, code, w_param, l_param) -> _user32.CallNextHookEx:
+        if w_param not in _wm_mouse_key_code:
+            return _user32.CallNextHookEx(self.hooked, code, w_param, l_param)
+        if w_param == _wm_mouse_key_code[0] and self.record_flag is True:
             x, y = position()
             self.record_queue.put(("mouse_left", x, y))
-        elif w_param == wm_mouse_key_code[1] and self.record_flag is True:
+        elif w_param == _wm_mouse_key_code[1] and self.record_flag is True:
             x, y = position()
             self.record_queue.put(("mouse_right", x, y))
-        elif w_param == wm_mouse_key_code[2] and self.record_flag is True:
+        elif w_param == _wm_mouse_key_code[2] and self.record_flag is True:
             x, y = position()
             self.record_queue.put(("mouse_middle", x, y))
-        return user32.CallNextHookEx(self.hooked, code, w_param, l_param)
+        return _user32.CallNextHookEx(self.hooked, code, w_param, l_param)
 
-    def _get_function_pointer(self, function):
+    def _get_function_pointer(self, function) -> WINFUNCTYPE:
         win_function = WINFUNCTYPE(c_int, c_int, c_int, POINTER(c_void_p))
         return win_function(function)
 
-    def _start_listener(self):
+    def _start_listener(self) -> None:
         pointer = self._get_function_pointer(self._win32_hook_proc)
         self._set_win32_hook(pointer)
         message = MSG()
-        user32.GetMessageA(byref(message), 0, 0, 0)
+        _user32.GetMessageA(byref(message), 0, 0, 0)
 
-    def record(self, want_to_record_queue):
+    def record(self, want_to_record_queue) -> None:
         self.record_flag = True
         self.record_queue = want_to_record_queue
         self.start()
 
-    def stop_record(self):
+    def stop_record(self) -> Queue:
         self.record_flag = False
         self._remove_win32_hook_proc()
         return self.record_queue
 
-    def run(self):
+    def run(self) -> None:
         self._start_listener()
 
 
-if __name__ == "__main__":
-    win32_mouse_listener = Win32MouseListener()
-    record_queue = Queue()
-    win32_mouse_listener.record(record_queue)
-    from time import sleep
-    sleep(3)
-    temp = win32_mouse_listener.stop_record()
-    for i in temp.queue:
-        print(i)
 
 
